<p align="center" style="background=#333">
    <img src="https://github.com/TechPenguineer/chem.py/blob/main/public/logo.png" width="300px">
    <h1 align="center">Chemistry in python</h1>
</p>

# Usage

```py
from chempy import *
```